OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Não foi possível carregar o modelo",
    "Saved" : "Guardado",
    "Reset" : "Repor",
    "An error occurred" : "Ocorreu um erro",
    "Sharing email - public link shares (HTML)" : "Correio eletrónico da partilha - partilhas de ligação pública (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "Correio eletrónico da partilha - partilhas de ligação pública (texto simples)",
    "Sharing email (HTML)" : "Partilhar correio eletrónico (HTML)",
    "Sharing email (plain text fallback)" : "Partilhar mensagem (texto sem formatação)",
    "Lost password mail" : "Perdi a palavra passe do correio",
    "New user email (HTML)" : "Novo e-mail de utilizador (HTML)",
    "New user email (plain text fallback)" : "Novo e-mail do utilizador (texto simples)",
    "Activity notification mail" : "E-mail de notificação da atividade",
    "Mail Templates" : "Modelos de Correio",
    "Theme" : "Tema",
    "Template" : "Modelo",
    "Please choose a template" : "Por favor, escolha um modelo",
    "Save" : "Guardar"
},
"nplurals=2; plural=(n != 1);");
